#!/bin/sh
#
# This scriptlet is desgined specifically to add calls to support 
# the use of the backmod.sh and unmod.sh code as an include function
# on a module by module basis such that you can pass the following to your
# modules to separate the two clearly:
#
#	foo.sh -b (backup anything in the SAVEFILE variable for $0)
#	foo.sh -u (recover anything in the SAVEFILE variable for $0)
#

umask 022

# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#


#
# Basic TITANHOME for relative path information
#
if [ -r ./.trunrc ]; then 
. ./.trunrc 
export TITANHOME 
else 
TITANHOME=`pwd`
export TITANHOME
fi 

. $TITANHOME/lib/misc_functions.sh

# MYNAME=`basename $0`
# did things work out or not?
# action=`sanity_check $MYNAME $1`
# if test $? -ne 0 ; then
#         exit 1
# fi
# export action

#
Check() {

. ./.trunrc

if [ -z "`grep backmod.sh $2`" -o -z "`grep unmod.sh $2`" ]; then
 t_echo 1 "Needs backmod.sh and unmod.sh cases in $2 - FAILS CHECK"
 else
 t_echo 1 "Backup/Recover backmod.sh/unmod.sh in place - PASSES CHECK"
fi

}

Fix() {

. ./.trunrc
export TITANHOME

if [ -r ${TITANHOME}/lib/backmod.sh ]; then

t_echo 1 "Adding backmod.sh and unmod.sh cases to $2.."

 if [ -r ${TITANHOME}/lib/mkbackmod.skel ]; then

#
# Append versus edit if the skeleton is in place..
#
  t_echo 1 "Appending action.skel and rchomeerr.skel to $2.."
  /bin/cat ${TITANHOME}/lib/mkbackmod.skel >>${2}
 else
#
# If no skeleton case statements edit like we did originally below...
#
ex - $2 <<EOEF
g/case \$action in/s/ in/ in
:r ${TITANHOME}/lib/action.skel
g/(I)ntro\/(V)erify\/(F)ix/s/$/
:r ${TITANHOME}/lib/rchomeerr.skel
w!
wq!
EOEF

fi

 else
  t_echo 1 "Could not locate backmod.sh - FAILS - No work done"
fi

t_echo 1 "Done fixing TITANHOME variable in $2..."

}

Intro() {
cat << EOF_INTRO
 
This adds some new/additional case statements into each module passed as $1 to
support the use of the backtit and untit code as an include functions on a
module by module basis such that you can pass the following to your
modules. If foo.sh is passed:

Run as:-[Bb] Will backup everything in the SAVEFILES variable and store by
	     time and date using "backmod.sh" for recovery with "unmod.sh" 
Run as:-[Uu] Will recover everything in the SAVEFILES variable as stored by
	     time and date using "unmod.sh" 

To add backup/recover functionality to any module:

Run as: $0 -v <module> to verify action case statement to support backup/recover 
Run as: $0 -F <module> to fix action case statement to support backup/recover 
	as functions in your module using backmod.sh and unmod.sh respectively

$TITANHOME/lib files used = action.skel, rchomeerr.skel, backmod.sh, unmod.sh

EOF_INTRO
}
 
#
# Need an arg for module to work on as requested....
#
if [ $# -lt 1 ]; then
    t_echo 1 "   ERROR:Usage $MYNAME -i | -[vf] <module-name>"
    exit 1
fi
#
# Main
action=$1
# t_echo 1 "Got $action"
case $action in
    -[Ii]*)
     Intro
    ;;
    -[Ff]*)
     Fix $@
    ;;
    -[Vv]*)
     Check $@
    ;;
    *)
    t_echo 1 " "
    t_echo 1 "	ERROR:Invalid arg $action"
    t_echo 1 "	ERROR:Usage $MYNAME -i | -vf <module-name>"
    t_echo 1 "	Run with -[Ff][Hh] to fix TITANHOME path in module"
    t_echo 1 "	Run with -[Ff][Cc] to add backtit/untit support to module"
    t_echo 1 " "
    # exit 1
   ;;
esac
