:
# ftpusers.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
RUNDATE=`/bin/date +%m%d%y%H%M%S`
SAVEFILES='${FTPUFILE}'
FTPUFILE='/etc/ftpusers'
OS=`uname -r`
HOST=`uname -n`

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

case $OS in
  5*)
   LOCALFTPUSERS=`awk -F":" '($3 < 100) || ($3 > 60000) {print $1}' /etc/passwd`
  ;;
  4*)
   LOCALFTPUSERS=`awk -F":" '($3 < 100) || ($3 > 65000) {print $1}' /etc/passwd`
  ;;
 *)
   LOCALFTPUSERS=`awk -F":" '($3 < 100) || ($3 > 65000) {print $1}' /etc/passwd`
;;
esac

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi


Intro() {

cat << EOF

   $MYNAME : This program looks for ${FTPUFILE} and if not found creates it.
   If it is found it saves the origional then adds all users with UID
   less than 100 and greater than 60000 and sets the mode on the file.

   Default ftpusers list in DEFFTPUSERS for most Unix variants we leave root
   in by default, not recommended but during initial Titan installs you may
   need to ftp back in as root. Once you are comfortable with your setup
   swap these out and re-run $MYNAME.  Or, simply add root to the ${FTPUFILE}
   file on this host.

   # Strict - no root
   # DEFFTPUSERS="root daemon sys bin adm lp smtp uucp nuucp listen nobody 
     noaccess news ingres audit admin sync nobody4"

   # Root allowed...
   # DEFFTPUSERS="daemon sys bin adm lp smtp uucp nuucp listen nobody noaccess 
     news ingres audit admin sync nobody4"


EOF

}

#
# Default ftpusers list for most Unix variants
#
# Strict - no root
# DEFFTPUSERS="root daemon sys bin adm lp smtp uucp nuucp listen nobody noaccess news ingres audit admin sync nobody4"
#
# Root allowed...
DEFFTPUSERS="daemon sys bin adm lp smtp uucp nuucp listen nobody noaccess news ingres audit admin sync nobody4"

Fix() {

        if [ -f ${FTPUFILE} ]; then
        t_echo 2 " ${FTPUFILE} already exists; saving a copy "
        /bin/cp ${FTPUFILE} ${FTPUFILE}-preTitan-${RUNDATE}
		if [ $? -ne 0 ]
       		then
                 t_echo 1
                 t_echo 1 "       ERROR - Could not rename ${FTPUFILE}; exiting"
			exit 1
		fi
	fi

 
# if there is a file ${FTPUFILE} append it
 
if [  -f ${FTPUFILE} ]
then
	t_echo 2 " Checking and appending names to ${FTPUFILE}..."
	t_echo 2 " Checking default ftpusers names..."
	/bin/touch ${FTPUFILE}
	for USER in $DEFFTPUSERS
	 do
	   grep "^$USER" ${FTPUFILE} >/dev/null 2>&-
	   if [ $? -ne 0 ]; then
	      ftpx=1
              echo $USER >>${FTPUFILE}
	   else
              t_echo 1 " $USER in ${FTPUFILE} - PASSES CHECK"
	   fi
	 done

	t_echo 2 " Checking your local ftpusers names..."
	for USER in $LOCALFTPUSERS
	 do
	   grep "^$USER" ${FTPUFILE} >/dev/null 2>&-
	   if [ $? -ne 0 ]; then
	      ftpx=1
              echo $USER >>${FTPUFILE}
	   else
              t_echo 1 "        $USER in ${FTPUFILE} - PASSES CHECK"
	   fi
	 done
	 if test "X$ftpx" != "X" ; then
	    t_echo 2 " Added users to ${FTPUFILE}."
	 fi

fi


# if there isn't a file ftpuser, create it
if [  ! -f ${FTPUFILE} ]
then
 t_echo 2 " Creating ${FTPUFILE} disallowing ftp to the following users:"
 t_echo 2 $DEFFTPUSERS
 t_echo 2 " "

	/bin/touch ${FTPUFILE}
 t_echo 2 " Installing default ftpusers names..."
	for USER in $DEFFTPUSERS
	 do
 echo $USER >>${FTPUFILE}
	done

 t_echo 2 " Installing your local ftpusers names..."
	for USER in $LOCALFTPUSERS
	 do
	grep "^$USER" ${FTPUFILE} >/dev/null 2>&-
	if [ $? -ne 0 ]; then
 echo $USER >>${FTPUFILE}
	else
 t_echo 1 "       $USER in ${FTPUFILE} - PASSES CHECK"
	fi
	done

fi

# chmod it when done
/bin/chmod 644 ${FTPUFILE}

} # End Fix


Check() {

t_echo 2 " Checking ${FTPUFILE} file for default matches...."
   for USER in $DEFFTPUSERS
    do
    grep "^$USER" ${FTPUFILE} >/dev/null 2>&-
     if [ $? -ne 0 ]; then
     t_echo 0 "        $USER not in ${FTPUFILE} - FAILS CHECK" 
     else
     t_echo 1 "        $USER in ${FTPUFILE} - PASSES CHECK"
     fi
    done

t_echo 2 " "
t_echo 2 " Checking ${FTPUFILE} file for local matches...."
   for USER in $LOCALFTPUSERS
    do
    grep "^$USER" ${FTPUFILE} >/dev/null 2>&-
     if [ $? -ne 0 ]; then
     t_echo 0 "        $USER not in ${FTPUFILE} - FAILS CHECK"
     else
     t_echo 1 "        $USER in ${FTPUFILE} - PASSES CHECK"
     fi
    done

}

action=$1
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
        Fix
        ;;
        -[Vv]*)
	if [ -f ${FTPUFILE} ]; then
           t_echo 2 "          The ${FTPUFILE} file exists..."
           t_echo 2 "          Your default ftpusers names: "
           t_echo 2 " "
           t_echo 2 $DEFFTPUSERS
           t_echo 2 " "
           t_echo 2 "       Your local ftpusers names: "
           t_echo 2 " "
           t_echo 2 $LOCALFTPUSERS
           t_echo 2 " "
           Check
	else
           t_echo 0 "       No ${FTPUFILE} file in place - FAILS CHECK"
           t_echo 1 "       Should contain at least: "
           t_echo 1 " "
 	for USER in $DEFFTPUSERS
    	   do
              t_echo 1 " $USER"
 	done
        t_echo 2 " "
 	exit 1
	fi
        ;;
        *)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac

