:
# fix-cronpath.sh
# version 4.0.beta4
# bpowell 2001-6-3 added in missing fi
# bpowell fixed problem with "chmod o-w ." should be "chmod o-w $DIR

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

#JKR fix to add users for cron.allow, at.allow separated by colon
# by default titan only allows root if you wish to allow others, add them
# seperated by a colon, as in the example by JKR
RF_ALLOWUSERS="root"
# RF_ALLOWUSERS="root:oracle"


# setup
IFS=:
TITANHOME=`pwd` 
export TITANHOME 

PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/cron.d/cron.allow /etc/cron.d/at.allow'
OS=`uname -r`
HOST=`uname -n`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh

Intro() {

cat << EOF

 $MYNAME - This program looks at /var/spool/cron/crontabs/root
 and changes the directory permissions to be owned by root and 
 non-writable by group or other. Then chown the files run by roots
 cron to be owned by root. Lastly it creates a /etc/cron.d/cron.allow
 and /etc/cron.d/at.allow and adds the user root to the file. 

EOF

}

Fix() {

IFS=:
# Corrected a typo with "nfsfind"
LIST=/etc:/etc/cron.d:/usr:/usr/sbin:/usr/lib:/usr/lib/fs:/usr/lib/fs/nfs:/usr/bin:/etc/cron.d/logchecker:/usr/lib/newsyslog:/usr/lib/fs/nfs/nfsfind:/usr/bin/rdate:/usr/sbin/rtc 

#
# For any directories in the list check permissions
#

    for DIR in $LIST
      do
       # Changed the IF structure - the logic was wrong and there was an error
       # with /usr/sbin/rtc because it didn't exist
       if [ -d $DIR ]
        then
	# Directories should always be owned by root if root cron executes it
	chown root $DIR
         if ls -dl $DIR | grep -s "^........w"
          then
           t_echo 1 "       $DIR is writable by world; fixing."
           chmod o-w $DIR
         fi

         if ls -dl . | grep -s "^.....w"
          then
           t_echo 1 "       $DIR is writable by group; fixing"
           chmod g-w $DIR
	else
	t_echo 2 ""
	 fi
      fi
    done
t_echo 2 "    "

#
# Now parse the files list
#
  for FILE in $LIST
  do
    if test -f $FILE
     then
#      t_echo 1 "    " $FILE ownership being changed to root 
      chown root $FILE
    fi
  done

#
# Build cron.allow if it does not exist in this section
#
t_echo 2 "    "

  if [ -f /etc/cron.d/cron.allow ]; then
   t_echo 2 " /etc/cron.d/cron.allow already exists; moving it aside"
   mv /etc/cron.d/cron.allow /etc/cron.d/cron.allow.ORIG.$DATE

    if [ $? -ne 0 ]; then
     t_echo 1 " "
     t_echo 1 " Could not rename cron.allow -  ERROR"
     exit 1
    fi
  fi

if [  ! -f /etc/cron.d/cron.allow ]; then
 t_echo 2 " Creating /etc/cron.d/cron.allow with permitted user(s)"
 touch /etc/cron.d/cron.allow
 for RF_USER in $RF_ALLOWUSERS; do
 echo $RF_USER >> /etc/cron.d/cron.allow
done

/bin/chmod 644 /etc/cron.d/cron.allow
fi

#
# Build at.allow if it does not exist in this section
#

t_echo 2 "    "

 if [ -f /etc/cron.d/at.allow ]; then
  t_echo 2 " /etc/cron.d/at.allow already exists; moving it aside"
  mv /etc/cron.d/at.allow /etc/cron.d/at.allow.ORIG.$DATE
  if [ $? -ne 0 ]; then
   t_echo 2 " "
   t_echo 1 " Could not rename at.allow  - ERROR"
   exit 1
  fi
 fi
 
if [  ! -f /etc/cron.d/at.allow ]; then
 t_echo 2 " Creating /etc/cron.d/at.allow with permitted user(s)"
 touch /etc/cron.d/at.allow
 for RF_USER in $RF_ALLOWUSERS; do
  echo $RF_USER >> /etc/cron.d/at.allow
done

/bin/chmod 644 /etc/cron.d/at.allow
fi

} 


Check() {

# Default chown/chmod stuff
# chown  root dirs and executables
# chmod 755 dirs and executables
# LIST= should be an awk script eventually to parse the contents of 
#       /var/spool/cron/crontabs/root and create  $LIST.
#

IFS=:
LIST=/etc:/etc/cron.d:/usr:/usr/sbin:/usr/lib:/usr/lib/fs:/usr/lib/fs/nfs:/usr/bin:/etc/cron.d/logchecker:/usr/lib/newsyslog:/usr/lib/fs/nfs/nsfind:/usr/bin/rdate:/usr/sbin/rtc 

#
# For any directories in the list check permissions
#

    for DIR in $LIST
      do
       if test -d $DIR
        then
         if ls -dl $DIR | grep -s "^........w"
          then
           t_echo 0 "       $DIR is writable by world - FAILS CHECK"
	t_echo 3 " "
	t_echo 3 "Titan Recommendation: (fix-cronpath.sh -f) Check roots crontab to ensure any root"
	t_echo 3 "run cron jobs cannot be trojaned. If a root run cron job executes a binary in"
	t_echo 3 "(say) /tmp/foo and that file is modifiable by another user, that user can execute"
	t_echo 3 "commands as root via the cron job. Ownership of everything run by roots cron "
	t_echo 3 "should be owned by root, file ownership and permissions should be set to only"
	t_echo 3 "be writable by root (not group) and cron.allow and at.allow should be created."
t_echo 3 " "
t_echo 3 "======================================================================== "
          else
           t_echo 1 "       $DIR is not writable by world - PASSES CHECK."
         fi

         if ls -dl $DIR | grep -s "^.....w"
          then
           t_echo 0 "       $DIR is writable by group - FAILS CHECK"
          else
           t_echo 1 "       $DIR is not writable by group - PASSES CHECK."
         fi
        fi
    done
t_echo 2 "    "

#
# Now parse the files list
#
  for FILE in $LIST
  do
    if test -f $FILE
     then
	OWNER=`ls -l $FILE | awk '{print $3}' `
	if [ $OWNER = "root" ] ; then
		t_echo 1 "    $FILE is owned by root - PASSES CHECK"
	else
		t_echo 0 "   $FILE ownership should be changed to root - FAILS CHECK"
	fi
    fi
  done

t_echo 2 "    "

  if [ -f /etc/cron.d/cron.allow ]; then
     t_echo 2 " Checking contents of cron.allow..."
     RF_LINECOUNT=`wc -l /etc/cron.d/cron.allow | awk '{print $1}'`
     RF_FOUNDUSERS=0
     for RF_USER in ${RF_ALLOWUSERS}; do
        RT=`grep "^${RF_USER}$" /etc/cron.d/cron.allow`
        if [ -z "$RT" ]; then
           t_echo 1 " cron.allow exists but does not contain $RF_USER"
	else
	   RF_FOUNDUSERS=`expr $RF_FOUNDUSERS + 1`
        fi
     done
     if [ $RF_FOUNDUSERS -lt $RF_LINECOUNT ]; then
        t_echo 0 "         cron.allow exists and allows other than allowed users to execute - FAILS CHECK "
     elif [ $RF_FOUNDUSERS -eq $RF_LINECOUNT ]; then
	t_echo 2 "         cron.allow has no unauthorized users - PASSES CHECK"
     fi
  else
     t_echo 0 "         No cron.allow file - FAILS CHECK"
     break
  fi

#
# Check for at.allow containing root in this section
#

t_echo 2 "    "

  if [ -f /etc/cron.d/at.allow ]; then
     t_echo 2 " Checking contents of at.allow..."
     RF_LINECOUNT=`wc -l /etc/cron.d/at.allow | awk '{print $1}'`
     RF_FOUNDUSERS=0
     for RF_USER in ${RF_ALLOWUSERS}; do
        RT=`grep "^${RF_USER}$" /etc/cron.d/at.allow`
        if [ -z "$RT" ]; then
           t_echo 1 " at.allow exists but does not contain $RF_USER"
        else
           RF_FOUNDUSERS=`expr $RF_FOUNDUSERS + 1`
        fi
     done
     if [ $RF_FOUNDUSERS -lt $RF_LINECOUNT ]; then
        t_echo 0 "         at.allow exists and allows other than allowed users to execute - FAILS CHECK "
     elif [ $RF_FOUNDUSERS -eq $RF_LINECOUNT ]; then
        t_echo 1 "         at.allow has no unauthorized users - PASSES CHECK"
     fi
  else
     t_echo 0 "         No at.allow file - FAILS CHECK"
     break
  fi

} 

action=$1
if [ -f /var/spool/cron/crontabs/root ]
 then
    t_echo 2 " File /var/spool/cron/crontabs/root exists; continuing"
 else
    t_echo 2 " User root doesn't seem to have a cron entry; exiting"
    exit 1
fi
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
        Fix
        ;;
        -[Vv]*)
        Check
        ;;
        *) 
          t_echo 1 " " 
          t_echo 1 "        ERROR:Invalid arg $action" 
          t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntroduction/(V)erify/(F)ix" 
          t_echo 1 " " 
        ;; 
        esac 

