:
# bsm.sh
# version 3.0.5 Tue Feb 16 12:23:36 PST 1999
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 


# This module Contributed by:
# Jason R. Rhoads                             mailto:jasonr@net.com
# Network Equipment Technologies, Inc.           http://www.net.com

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/usr/sbin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/security/audit_control'

OS=`uname -r`

# auditing flags referenced in audit_control(4)
AUDIT_FLAGS="lo,ad,-all,^-fm"
AUDIT_NAFLAGS="lo,ad"

# audit_warn alias
AUDIT_WARN="root"

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF

 $MYNAME : This program verifies that the Basic Security Module (BSM) is enabled
 and configures auditing events by modifing /etc/security/audit_control.

 Auditing is configured to log all logins, admin operations (whether or not
 they succeed), as well as failures of all types except object attribute
 access failures.  Auditing flags can be changed by editing this script.

 When run in Fix mode and BSM was not previously enabled, it will
 be neccessary to reboot.
 
EOF
}

#
# Enable BSM if neccessary and make changes to /etc/security/audit_control
#
Fix() {

 `/usr/sbin/auditconfig -getcond >/dev/null 2>&1 ` 
 if [ $? -eq 1 ]; then
   t_echo 2 "       Enabling BSM..."
   echo y | /etc/security/bsmconv
 fi

 if [ -f /etc/security/audit_control ]; then
    t_echo 2 " File /etc/security/audit_control exists saving and continuing..."
    cp /etc/security/audit_control /etc/security/audit_control.ORIG.$DATE
   else
    t_echo 1 "       ERROR - File /etc/security/audit_control does not exist "
    exit 1
 fi

  t_echo 2 " Setting audit paramaters..."
ed - /etc/security/audit_control << EOEF
g/^flags:/d
g/^naflags:/d
w
q
EOEF

 echo "flags:$AUDIT_FLAGS"     >> /etc/security/audit_control
 echo "naflags:$AUDIT_NAFLAGS" >> /etc/security/audit_control

 # Signal the audit daemon to read the control file
 /usr/sbin/audit -s

 # add audit_warn alias if needed
 grep "^audit_warn:" /etc/aliases > /dev/null 2>&-
 if [ $? -eq 1 ]; then
  t_echo 2 " Adding audit_warn alias..."
  echo "audit_warn: $AUDIT_WARN" >> /etc/aliases
  /usr/bin/newaliases 
 fi
}

#
# Verify audit configuration here...
#
Verify() {

 res=`/usr/sbin/auditconfig -getcond` 
 if [ "$res" != "audit condition = auditing" ]; then
   t_echo 1 "       WARNING - BSM is not enabled"
 fi

 if [ -f /etc/security/audit_control ]; then
   t_echo 2 " File /etc/security/audit_control exists checking contents...."
  else
   t_echo 1 "       ERROR - File /etc/security/audit_control does not exist - exiting"
   exit 1
 fi

 grep "^flags:$AUDIT_FLAGS" /etc/security/audit_control >/dev/null 2>&- 
 if [ $? -eq 0 ]; then
   grep "^naflags:$AUDIT_NAFLAGS" /etc/security/audit_control >/dev/null 2>&-
   if [ $? -eq 0 ]; then
 	t_echo 1 "        auditing already configured - PASSES CHECK"
	exit 1
   fi
 fi
 	t_echo 0 "        auditing not configured - FAILS CHECK"
}

#
# Main section here

action=$1
case $action in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	  Fix
	 ;;
	 -[Vv]*)
	  Verify
	 ;;
	 *)
 	 t_echo 1 " "
	 t_echo 1 "        ERROR:Invalid arg $action"
	 t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 	 t_echo 1 " "
 	;;
esac
