:
# defloginparams.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
#This module by Mitko Stoyanov, August 1999
 
TITANHOME=`pwd`
MYNAME=`basename $0`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
DATE=`/bin/date +%m%d%y%H%M`
RUNDATE=`/usr/bin/date +%Y%m%d%H%M`
SAVEFILES='/etc/default/login'

. misc_functions.sh

case "`uname -r`" in
5.[2-9]*) ;;
*)
        t_echo 1 "$MYNAME : Only supported on SunOS 5.2 thru 5.8" 1>&2
        t_echo 1 "      (Solaris 2.2 through Solaris 8)" 1>&2
        exit 1;;
esac


OS=`uname -r`

# BEGIN CONFIGURABLE STUFF

# file where login defaults are kept
LOGINDEFFILE="/etc/default/login"

# If CONSOLE is set, root can only login on that device.
LCONSOLE=/dev/console

# UMASK sets the initial shell file creation mode mask.  See umask(1).
LUMASK=022

# SYSLOG determines whether the syslog(3) LOG_AUTH facility should be used
# to log all root logins at level LOG_NOTICE and multiple failed login
# attempts at LOG_C
LSYSLOG=YES

# TIMEOUT sets the number of seconds (between 0 and 900) to wait before
# abandoning a login session.
LTIMEOUT=120

# PASSREQ determines if login requires a password.
LPASSREQ=YES

# ALTSHELL determines if the SHELL environment variable should be set
LALTSHELL=YES

# END CONFIGURABLE STUFF

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro() {
cat << EOF_INTRO
$MYNAME : This script checks/fixes the /etc/default/login file.
Change $MYNAME configurable parameters to those required by YOUR Site Security
Policy. The default values that Titan picks are:

# If CONSOLE is set, root can only login on that device.
LCONSOLE=/dev/console

# UMASK sets the initial shell file creation mode mask.  See umask(1).
LUMASK=022

# SYSLOG determines whether the syslog(3) LOG_AUTH facility should be used
# to log all root logins at level LOG_NOTICE and multiple failed login
# attempts at LOG_C
LSYSLOG=YES

# TIMEOUT sets the number of seconds (between 0 and 900) to wait before
# abandoning a login session.
LTIMEOUT=120

# PASSREQ determines if login requires a password.
LPASSREQ=YES

# ALTSHELL determines if the SHELL environment variable should be set
LALTSHELL=YES

EOF_INTRO
}

Check() {

#There should be only ONE uncommented <PARAM>= line for each parameters
#and it should be exactly the same we want it to be. 

   if [ -r "$LOGINDEFFILE" ];then 
   if [ "`grep -cs \"^CONSOLE=${LCONSOLE}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*CONSOLE=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults CONSOLE - PASSES CHECK "
   else
      t_echo 0 "  login defaults CONSOLE - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^UMASK=${LUMASK}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*UMASK=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults UMASK - PASSES CHECK "
   else
      t_echo 0 "  login defaults UMASK - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^SYSLOG=${LSYSLOG}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SYSLOG=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults SYSLOG - PASSES CHECK "
   else
      t_echo 0 "  login defaults SYSLOG - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^TIMEOUT=${LTIMEOUT}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*TIMEOUT=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults TIMEOUT - PASSES CHECK "
   else
      t_echo 0 "  login defaults TIMEOUT - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^PASSREQ=${LPASSREQ}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*PASSREQ=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults PASSREQ - PASSES CHECK "
   else
      t_echo 0 "  login defaults PASSREQ - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^ALTSHELL=${LALTSHELL}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*ALTSHELL=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults ALTSHELL - PASSES CHECK "
   else
      t_echo 0 "  login defaults ALTSHELL - FAILS CHECK" 
   fi
  else 
      t_echo 0 "  passwd $LOGINDEFFILE missing - FAILS CHECK" 
  fi


}


Fix() {

   if [ -r "$LOGINDEFFILE" ] && \
      [ "`grep -cs \"^CONSOLE=${LCONSOLE}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*CONSOLE=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^UMASK=${LUMASK}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*UMASK=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^SYSLOG=${LSYSLOG}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SYSLOG=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^TIMEOUT=${LTIMEOUT}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*TIMEOUT=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^PASSREQ=${LPASSREQ}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*PASSREQ=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^ALTSHELL=${LALTSHELL}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*ALTSHELL=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   $LOGINDEFFILE entries - PASSES CHECK "
   else
      t_echo 0 "  $LOGINDEFFILE entries - FAILS CHECK" 
      t_echo 2 "  Fixing "$LOGINDEFFILE" now...." 
        if [ ! -f "$LOGINDEFFILE" ];then
            touch "$LOGINDEFFILE" && chmod 444 "$LOGINDEFFILE" \
            && chown root "$LOGINDEFFILE" &&  chgrp sys "$LOGINDEFFILE"
        else
             cp -p "$LOGINDEFFILE" "$LOGINDEFFILE".${RUNDATE}
        fi
	ed - "$LOGINDEFFILE" <<- __INPUT__ 
	g/^[^#]*SYSLOG=/d
	g/^[^#]*UMASK=/d
	g/^[^#]*CONSOLE=/d
	g/^[^#]*TIMEOUT=/d
	g/^[^#]*PASSREQ=/d
	g/^[^#]*ALTSHELL=/d
	a
	#Entries created by Titan file $MYNAME at $RUNDATE
	.
	a
	#
	.
	a
	SYSLOG=${LSYSLOG}
	.
	a
	CONSOLE=${LCONSOLE}
	.
	a
	UMASK=${LUMASK}
	.
	a
	TIMEOUT=${LTIMEOUT}
	.
	a
	PASSREQ=${LPASSREQ}
	.
	a
	ALTSHELL=${LALTSHELL}
	.
	w
	q
	__INPUT__
      if [ "$?" -ne 0 ];then
        t_echo 1 "  Fixing "$LOGINDEFFILE" FAILED - check the file" 
        exit 1
        else 
        t_echo 2 "  "$LOGINDEFFILE" FIXED" 
      fi
   fi


}

 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
;;
esac

