:
# fix-stack.sol2.6.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/system'

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh


case "`uname -r`" in
5.[6789]*) ;;
*)
        t_echo 1 "$MYNAME ERROR - This script is Only supported on Solaris 2.6 and newer, please use one of the other scripts for your OS "
        exit 1;;
esac


Intro() {

cat << EOF

 $MYNAME - Adds the following entry into /etc/system to force all users 
 zero-fill-on-demand pages are marked rw- instead of rwx on the
 stack

    * Don't allow executing code on the stack
    set noexec_user_stack = 1

    * And log it when it happens.
    set noexec_user_stack_log = 1

EOF

}

Fix() {

        if [ -f /etc/system ]; then
         t_echo 2 " Saving /etc/system to /etc/system.ORIG.$DATE"
         cp -p /etc/system /etc/system.ORIG.$DATE
          if [ $? -ne 0 ]; then
           t_echo 1 "     ERROR:Could not rename /etc/system; exiting"
           exit 1
	  else
           t_echo 1 " Changing /etc/system for stack protecting"
           echo "* Don't allow executing code on the stack" >>/etc/system
           echo "set noexec_user_stack = 1" >>/etc/system
           echo "* And log it when it happens." >>/etc/system
           echo "set noexec_user_stack_log = 1" >>/etc/system
           chmod 644 /etc/system
           t_echo 2 "Done ... "
          fi
	else
         touch /etc/system
           t_echo 1 "         Creating /etc/system to protect the stack"
 	   echo "* Don't allow executing code on the stack" >>/etc/system   
           echo "set noexec_user_stack = 1" >>/etc/system
           echo "* And log it when it happens." >>/etc/system
           echo "set noexec_user_stack_log = 1" >>/etc/system
         chmod 644 /etc/system
        fi

}

Check() {

        if [ -f /etc/system ]; then
         grep "set noexec_user_stack = 1" /etc/system | grep -v "#" >/dev/null 2>&-
         if [ $? -eq 0 ]; then
         t_echo 1 " Stack is already protected  - PASSES CHECK"
	 exit 1
         else
         t_echo 0 "        Stack Protection not currently set - FAILS CHECK "
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (fix-stack.sol2.6.sh -f) Set the systems such that all user "
        t_echo 3 "zero-fill-on-demand pages are marked rw- instead of rwx. This prevents many stack "
        t_echo 3 "smashing codes from being able to create suid executable code. "
        t_echo 3 "Titan adds the following to /etc/system  "
        t_echo 3 "  "
        t_echo 3 "    * Don't allow executing code on the stack "
        t_echo 3 "      set noexec_user_stack = 1 "
        t_echo 3 "    * And log it when it happens. "
        t_echo 3 "      set noexec_user_stack_log = 1 "
        t_echo 3 "  "
        t_echo 3 "Note - *requires a system reboot "
        t_echo 3 " "
        t_echo 3 "======================================================================== "

         fi
        else
         t_echo 1 "        No /etc/system file - No verification possible"
         exit 1
        fi

}

action=$1

   case ${action} in
	-[Ii]*)
	Intro
	;;
	-[Ff]*)
	Fix
	;;
	-[Vv]*)
	Check	
	;;
	*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $0 -[ivf] (I)ntro/(V)erify/(F)ix"
	exit 1;;
	esac

#finis
